@@ -11,7 +11,7 @@ use warnings 'all';
 use Benchmark qw( :all :hireswallclock );
 
 use lib 't/lib';
-#use MooseState;
+use MooseState;
 #use MoState;
 use State;
 
@@ -27,7 +27,7 @@ my $results = timethese(100_000, {
   blessed_hashref => \&blessed_hashref,
   hashref         => \&hashref,
   vso             => \&vso,
-#  moose           => \&moose,
+  moose           => \&moose,
 #  mo              => \&mo,
 });
 
